/* SPDX-License-Identifier: GPL-2.0+ */
/*
 * Copyright (C) 2020 xkwy2018.cn
 *
 * Configuration settings for the xkwy Tiny4412 (EXYNOS4412) board.
 */

#ifndef __CONFIG_TINY4412_H
#define __CONFIG_TINY4412_H

#include <configs/exynos4-common.h>

#define CONFIG_EXYNOS4210               1       /* for spl dmc&clock */

#define CONFIG_MACH_TYPE                MACH_TYPE_TINY4412

#define CONFIG_CLK_1000_400_200

/* Dual Samsung's DDR3 K4B4G1646D-BCK0 (total: 8Gbit) */
#define PHYS_SDRAM_1                    0x40000000
#define SDRAM_BANK_SIZE                 SZ_1G
#define CONFIG_SYS_SDRAM_BASE           PHYS_SDRAM_1

#define CONFIG_SYS_LOAD_ADDR            (CONFIG_SYS_SDRAM_BASE + SZ_32M)
#define CONFIG_LOADADDR                 0x42000000


/* copy form \linux\kernel\4.15.12\drivers\tty\tty_baudrate.c  static const speed_t baud_table[] */
#define CONFIG_SYS_BAUDRATE_TABLE       {0, 50, 75, 110, 134, 150, 200, 300, 600, 1200, 1800, 2400, 4800,  \
                                        9600, 19200, 38400, 57600, 115200, 230400, 460800,              \
                                        500000, 576000, 921600, 1000000, 1152000, 1500000, 2000000,     \
                                        2500000, 3000000, 3500000, 4000000}

#define CONFIG_SYS_MONITOR_BASE    0x00000000

/* Power Down Modes */
#define S5P_CHECK_SLEEP                 0x00000BAD
#define S5P_CHECK_DIDLE                 0xBAD00000
#define S5P_CHECK_LPA                   0xABAD0000


#define CONFIG_SYS_MMC_ENV_DEV          0

#define CONFIG_SPL_MAX_FOOTPRINT        (14 * 1024)

#define CONFIG_SYS_INIT_SP_ADDR         0x02040000

/*
 *    SD Card layout:
 *    +-----+-----+----------+-----+----------------+-------+
 *    | 0K5 | 8K  | 14K(BL2) | 1K5 |     936KiB     |  64K  |
 *    | MBR | BL1 | spl.bin  |     | u-boot-dtb.bin | u-env |
 *    +-----+-----+----------+-----+----------------+-------+
 *
 *    eMMC layout: (Boot Capacity: 4 MiB ENH)
 *    +-----+----------+-----------+----------------+-------+
 *    | 8K  | 14K(BL2) |    2K     |     936KiB     |  64K  |
 *    | BL1 | spl.bin  |           | u-boot-dtb.bin | u-env |
 *    +-----+----------+-----------+----------------+-------+
 */
/* U-Boot copy size from boot Media to DRAM.*/
#define BL2_START_OFFSET	(1 + 0x6000/512)
#define BL2_SIZE_BLOC_COUNT	(936*2)

#endif    /* __CONFIG_H */
